from .main import print_hi
from pymavlink import mavutil
def a(str):
    print("hi")
    master = mavutil.mavlink_connection(str)
    # Wait a heartbeat before sending commands
    master.wait_heartbeat()
    # Choose a mode



from distutils.core import setup
import setuptools

VERSION = "0.0.12"  # BURAYI AKLINIZDA TUTUN (Değiştirebilirsiniz)
long_description = ""
with open("README.md", "r", encoding="utf-8") as file:
    long_description = file.read()

setup(
    name='planekit',  # How you named your package folder (MyLib)
    packages=setuptools.find_packages(),
    # Start with a small number and increase it with every change you make
    version='0.0.12',
    # Chose a license from here: https://help.github.com/articles/licensing-a-repository
    license='MIT',
    # Give a short description about your library
    description='ASD',
    long_description=long_description,
    long_description_content_type="text/markdown",
    author='Musa SEN',  # Adınızı soyadınız yazın
    author_email='m42@gmail.com',  # E-posta adresiniz
    # Provide either the link to your github or to your website
    url='https://github.com/GITHUB_HESABI/PAKET_İSMİ',
    # I explain this later on
    download_url=f'https://github.com/GITHUB_HESABI/PAKET_İSMİ/archive/{VERSION}.tar.gz',
    # Keywords that define your package best
    keywords=['Alakalı', 'kelimeler'],
    # install_requires=[], # Bağımlılıklar
    classifiers=[
        # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        'Development Status :: 3 - Alpha',
        # Define that your audience are developers
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',  # Again, pick a license
        # Specify which pyhton versions that you want to support
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    # Komut isteminden kullanılacaksa, main'e verilen yol
    # entry_points={
    #     # Komut isteminden çalıştırma
    #     # örndeğin: ypackage
    #     # Kullanım: 'ypackge = ypackage.ypackage:main
    #     'console_scripts': [
    #         'komut_ismi = dizin.dosya:main',
    #     ]
    # },
)
